#this script can be used to run all analyses descriped in the regent honeyeater hyRAD paper.
#It is intented to run line-by-line as an introduction to population genomic analysis
#for users with limited experience with R. The script analyses variant call format (.vcf) 
#and comma delimited excel files (.csv) in GenAlEx format (converted via PGDspider). 
#It is worth scrutinising the format of the csv files in excel. This script uses the regent 
#honeyeater hyRAD dataset with a minumum read depth of DP=10 or 15. It can be easily modified to
#run on the datasets available online with minimum read depths of DP = 5 and DP = 15 - 100 by
#changing the file names where necessary. The 'in R' filtering can also be modified 
#easlily by running, not running or changing the criteria on the 'missingno' fuction
#(search for 'missingno' throughout the script).

#rm(list = ls())
setwd("E:/Genetics_24_2_18/DATA/VCF_new/VCF_new")

library(poppr)   
library(gtools)
library(magrittr)
library(vcfR)
library(adegenet)
library(splancs)
library(akima)
library(StAMPP)
#install.packages(Rcpp)
#install.packages(dplyr)
#install.packages(stringi)
#install.packages(httpuv)
library(hierfstat)
library(dartR)
#code to install and open dartR successfully, overcoming issues with SNPRelate and qvalue:
#install.packages("dartR")
#install.packages("PopGenReport")
# source("https://bioconductor.org/biocLite.R")
# biocLite("SNPRelate")
# source("https://bioconductor.org/biocLite.R")
# biocLite("qvalue")
library(qvalue)
library(PopGenReport)
library(SNPRelate)
library(RColorBrewer)
library(ape)
library(mmod)
library(MASS)
library(reshape2)
#install.packages("epiDisplay")
require(epiDisplay)
library(ggplot2)
library(lme4)
library(gtools)
library(ggthemes)
library(extrafont)
library(plyr)
library(scales)
library(ggpubr)
library(gridExtra)
library(stats)
library(plotrix)
library(reshape2)
library(cowplot)

#read in the unfiltered vcf:
regent.vcf <- read.vcfR("hyRAD_MUS_DP15_max100.f2.recode.vcf")
regent.vcf
#query the data in VCF before subsetting:
#quantifying missingness across all samples:
dp <- extract.gt(regent.vcf, element = "DP", as.numeric=TRUE)
myMiss15_100 <- apply(dp, MARGIN = 2, function(x){ sum(is.na(x)) })
myMiss15_100 <- myMiss15_100/nrow(regent.vcf)
write.csv(myMiss15_100, file = "myMiss_DP15_max100_unfiltered.csv") 
#Use the csv file to order the samples by period, read in and plot again.
#myMiss15_100 <- read.csv("myMiss_DP15_max100_unfiltered.csv", header = TRUE)
#convert data frame to vector:
#myMiss15_100 <- dplyr::pull(myMiss15_100 [,1:2])   
#str(myMiss15_100)

palette(brewer.pal(n=12, name = 'Set3'))
par(mar = c(12,4,4,2))
barplot(myMiss15_100, las = 2, col = 1:12, ylim = c(0,0.7),ylab = "% missing",
        main = "% missingness by sample, DP_15_100")


#query the variants for missingness:
myMiss15_100 <- apply(dp, MARGIN = 1, function(x){ sum(is.na(x)) })
myMiss15_100 <- myMiss15_100/ncol(regent.vcf@gt[,-1])
head(myMiss15_100)
par(mar = c(5,4,4,2))
hist(myMiss15_100, col = "#8DD3C7", xlab = "Missingness (%)", main = "histogram of % missingness per sample_DP15_100")

#evaluate the sequence depth:
dp <- extract.gt(regent.vcf, element = "DP", as.numeric=TRUE)
write.csv(dp, file = "sequence_depth_DP15_100.csv") #reorder the samples by time period before reading in
dp1<- read.csv(file="sequence_depth_dp15.csv") 
par(mar=c(5,4,4,2))
boxplot(dp1, col=3, las=3, ylim = c(0,150), main = "Sequence depth per sample DP15-100, 50% present", #can't see much on 2 plot
        ylab = "sequence depth (DP)")

#plot heatmap:
dp1<-as.matrix(dp1[,-1])
heatmap.bp(dp1[2:555,], rlabels = FALSE)

#convert VCF to genlight object:
gl.regent <- vcfR2genlight(regent.vcf)
#specify the ploidy
ploidy(gl.regent) <- 2
#add pop data to this keeping order the same
pop.data <- read.csv("RH_pop7.csv", sep = ",", header = TRUE)
#check samples all line up:
gl.regent@ind.names == pop.data$ID # ALL lined up

#set the population to age
pop(gl.regent) <- as.factor(pop.data$age)
popNames(gl.regent) # sample currently grouped by time period
gl.regent@ind.names


#use the genalex file to create a genind version of the same data:
#(if error comes up try changing geo=FALSE ti geo=TRUE)
gi.regent.gx <- read.genalex("hyRAD_MUS_DP15_max100.f2.csv", ploidy=2, geo=FALSE, 
                             genclone=FALSE, sep=",", recode=FALSE)
#A vector of the original names will be saved in the other slot under ind.names
gi.regent.gx
gi.regent.gx@pop #still grouped by time period

### Brenton checking some stuff before filter
div <- summary(gi.regent.gx)
div$NA.perc # % missing data 31%
div$pop.n.all
plot(div$Hobs,div$Hexp) # Possibly worth removing SNPs with Hobs < 0.6 or 0.7 - do after callrate filter

########################## FILTERING THE WHOLE DATASET TOGETHER #################################

#install.packages("devtools")
# require(devtools)
# install_version("dartR", version = "1.0.5", repos = "http://cran.us.r-project.org")

gl.regent.f <- gl.filter.callrate(gl.regent, method="loc", threshold = 0.65)#retains 320 SNPS
gl.regent.f #filter retained 320 SNPs
#convert to genind:
gi.regent.f <- gl2gi(gl.regent.f)

### checking some stuff after filter
div <- summary(gi.regent.f)
div$NA.perc # % missing data much better (23%)
div$pop.n.all
plot(div$Hobs,div$Hexp, xlab = "Observed heterozygosity",
     ylab = "Expected heterozygosity") # Heaps better, has removed most SNPs out of HWE - still a bunch w/ high Hobs

# Brenton checking missingness per sample
misscheck <- as.data.frame(gi.regent.f$tab)
misscheck$missingperloc <- rowSums(is.na(misscheck))
barplot(misscheck$missingperloc, names.arg = gi.regent.f$pop)
#Some of the old samples have high levels of missingness, but most seem alright.Not ordered by age

#split into museum v contemporary
#contemporary
levels(gi.regent.f$pop)
gl.regent_nomuseum <- gl.regent.f[gl.regent.f$pop!="old", ] #remove old samples
gi.regent_nomuseum <- gi.regent.f[gi.regent.f$pop!="old", ]
div <- summary(gi.regent_nomuseum)
div$NA.perc # 17.2% missing

#museum
gl.regent_museum <- gl.regent.f[gl.regent.f$pop =="old", ] #keep old samples
gi.regent_museum <- gi.regent.f[gi.regent.f$pop =="old", ]
div <- summary(gi.regent_museum)
div$NA.perc # 39% missing

############### EXPLORING HETEROZYGOSITY BY READ DEPTH AND SAMPLING PERIOD ###############
##########################################################################################

#read depth by heterozygosity, group etc for regent honeyeater data - see relevant plots
#in the supplementary data

#First import data and do some basic plotting of Ho (per genotype) vs seq depth per genotype

#import matrices of heterozygosity, depth and pop ID from CSV's created in Excel from GenAlEx format data

pop<-as.matrix(read.table("pop_15_100_60.csv",sep = ",",row.names=1,header=TRUE))

het<-as.matrix(read.table("het_15_100_60.csv",sep = ",",row.names=1,header=TRUE))

dep<-as.matrix(read.table("dep_15_100_60.csv",sep = ",",row.names=1,header=TRUE))

pop[1:10,1:10]
het[1:10,1:10]
dep[1:10,1:10]
dim(pop)
dim(dep)
dim(het)

#convert to table format
pop.m <- melt(pop)
het.m <- melt(het)
dep.m <- melt(dep)

#check
dim(pop.m)
dim(het.m)
dim(dep.m)

#combine data
pop_het_dep <- cbind (pop.m[,c(1:3)], het.m[,3],dep.m[,3])
dim(pop_het_dep)
head(pop_het_dep)
colnames(pop_het_dep) <- c("ID","SNP", "Group","Heterozygosity","Depth")
head(pop_het_dep)

#start plots again
hist(pop_het_dep$Depth)

#try something fancy i.e. plotting nomean het by depth intervals for the 3 groups

#first work out max depth for bin sizes
dep.max<- max(pop_het_dep$Depth)

#use aggregate.plot to plot moving average of Ho by depth
#Note that I used bin for ever value of depth
#change bin.time to dep.max/n, where n is 2, 5, 10 or whatever to get wider bins

aggregate.plot(pop_het_dep$Heterozygosity, by=pop_het_dep$Depth, grouping = pop_het_dep$Group,
               lwd=2, error="se", bin.method = "fixed", bin.time = dep.max, xlim=c(10,40),
               ylim=c(0.3,0.6),line.col=c("green","blue","yellow"),
               legend.site= "topleft",main = "nomean Ho by Depth")

################################################################################################################

#Now read in genotype data in 012 format to see how basic genetic diversity 
#stats in each sampling period are affected by seq depth threshold

#read in genotype file in 012 format
#This was from GenAlEx but recoded so eacxh genotype is 0 (AA), 1 (AB) or 2 (BB)

geno<-read.csv("012geno_15_100_60.csv",header=TRUE)
geno[1:10,1:10]
str(geno)
rownames(geno)<-geno[,1]
geno<-geno[,-c(1,2)]
geno[1:10,1:10]
geno.m<-as.matrix(geno)

#Made a function to calculate He, Ho abnd MAF (well, AF) by sampling period and see how these are affected by
#seq depth thresholds per genotytpe ranging from 1-100 (note basis data has NA for depth <10 already...)

hetbydepth <- function(x){
  
  geno.m2<-melt(geno.m)
  dim(geno.m2)
  names(geno.m2)
  dim(geno.m)
  geno.m2[1:10,1:3]
  max(geno.m2$value)
  
  #convert to allele freq per individual genotype (0,0.5,1,NA)
  geno.m2$Geno2<-(geno.m2$value/2)
  geno.m2[1:10,]
  
  geno_data<-cbind(pop_het_dep,geno.m2$Geno2)
  dim(geno_data)
  colnames(geno_data)[6]<-"Geno"
  geno_data<-na.omit(geno_data)
  dim(geno_data)
  geno_data[1:10,]
  
  #trial
  #x<-20
  
  geno_data1<-subset(geno_data, Depth>=x)
  
  #make SNP x Group column
  geno_data1$SNPGroup<-paste(geno_data1$SNP,geno_data1$Group,sep = ".")
  geno_data1[1:10,]
  
  #calculate expexted heterozygosity by group
  popgen<-aggregate(Geno~SNPGroup,data=geno_data1,FUN=mean,na.rm=TRUE)
  fun1<-function(x){length(!is.na(x))}
  genocount<-aggregate(Geno~SNPGroup,data=geno_data1,FUN=fun1)
  obshets<-aggregate(Heterozygosity~SNPGroup,data=geno_data1,FUN=sum, na.rm=TRUE)
  popgen$Heg<-2*popgen$Geno*(1-popgen$Geno)
  popgen$Hog<-obshets$Heterozygosity/genocount$Geno
  
  
  popSNP<-SNPGroup<-data.frame(do.call('rbind', strsplit(as.character(popgen$SNPGroup), '.', fixed=TRUE)))
  colnames(popSNP)<-c("SNP","Group")
  popgen<-cbind(popSNP$SNP,popSNP$Group,popgen)
  
  popgen[1:10,]
  dim(popgen)
  
  hist(popgen$Hog)
  hist(popgen$Heg)
  plot(popgen$Heg, popgen$Hog)
  
  #subset data greater than depth cutoff
  
  N<-subset(popgen,popSNP$Group=="N")
  
  str(popgen)
  popgen$pop
  N<-subset(popgen,popSNP$Group=="N")
  dim(N)
  N.maf<-mean(N$Geno)
  N.Ho<-mean(N$Hog)
  N.He<-mean(N$Heg)
  
  R<-subset(popgen,popSNP$Group=="R")
  dim(R)
  R.maf<-mean(R$Geno)
  R.Ho<-mean(R$Hog)
  R.He<-mean(R$Heg)
  
  M<-subset(popgen,popSNP$Group=="M")
  dim(M)
  M.maf<-mean(M$Geno)
  M.Ho<-mean(M$Hog)
  M.He<-mean(M$Heg)
  
  out<-cbind(M.He, M.Ho, M.maf, N.He, N.Ho, N.maf, R.He, R.Ho, R.maf)
  
  return(out[1,])
  
}

#Set the threshold values in a vector from 1-100
depth_cutoff<-seq(from = 1, to = 100, by = 1)

#Run the function (takes a little while)
divbydepth3 <-lapply(depth_cutoff, hetbydepth)

#Organise output
divbydepth2<-do.call(rbind,divbydepth3)
divbydepth<-as.data.frame(cbind(depth_cutoff,divbydepth2))

#Plot it
par(mfcol=c(3,3))
plot(divbydepth$depth_cutoff, divbydepth$M.He, xlab = "Depth threshold",ylab = "He", main = "Museum", ylim = c(0.24, 0.35))
plot(divbydepth$depth_cutoff, divbydepth$M.Ho, xlab = "Depth threshold",ylab = "Ho", ylim = c(0.24, 0.55))
plot(divbydepth$depth_cutoff, divbydepth$M.maf,xlab = "Depth threshold", ylab = "maf", ylim = c(0.4, 0.6))
plot(divbydepth$depth_cutoff, divbydepth$R.He, xlab = "Depth threshold",ylab = "He", main = "Recent", ylim = c(0.24, 0.35))
plot(divbydepth$depth_cutoff, divbydepth$R.Ho, xlab = "Depth threshold",ylab = "Ho", ylim = c(0.4, 0.55))
plot(divbydepth$depth_cutoff, divbydepth$R.maf, xlab = "Depth threshold",ylab = "maf", ylim = c(0.4, 0.6))
plot(divbydepth$depth_cutoff, divbydepth$N.He, xlab = "Depth threshold", ylab = "He", main = "New", ylim = c(0.24, 0.35))
plot(divbydepth$depth_cutoff, divbydepth$N.Ho, xlab = "Depth threshold", ylab = "Ho", ylim = c(0.4, 0.55))
plot(divbydepth$depth_cutoff, divbydepth$N.maf, xlab = "Depth threshold", ylab = "maf", ylim = c(0.4, 0.6))


############################# SPATIAL POP GEN ANALYSES ##################################
#########################################################################################
#back to the DP10 dataset:
regent.vcf <- read.vcfR("hyRAD_MUS_DP10.f2.recode.vcf")
gl.regent10 <- vcfR2genlight(regent.vcf)
#specify the ploidy
ploidy(gl.regent10) <- 2
gl.regent10
pop.data10 <- read.csv("RH_pop5.csv", sep = ",", header = TRUE)
#check samples all line up:
gl.regent10@ind.names == pop.data10$ID # ALL lined up

#set the population to age
pop(gl.regent10) <- as.factor(pop.data$age)
popNames(gl.regent10) # sample currently grouped by time period
gl.regent10.f <- gl.filter.callrate(gl.regent10, method="loc", threshold = 0.75)#retains 570 SNPS
gl.regent10.f #filter retained 570 SNPs
#convert to genind:
gi.regent10.f <- gl2gi(gl.regent10.f)
div <- summary(gi.regent10.f)
div$NA.perc

levels(gi.regent10.f$pop)
gl.regent10_nomuseum <- gl.regent10.f[gl.regent10.f$pop!="old", ] #remove old samples
gi.regent10_nomuseum <- gi.regent10.f[gi.regent10.f$pop!="old", ]
div <- summary(gi.regent10_nomuseum)
div$NA.perc # 5.5% missing

#museum
gl.regent10_museum <- gl.regent10.f[gl.regent10.f$pop =="old", ] #keep old samples
gi.regent10_museum <- gi.regent10.f[gi.regent10.f$pop =="old", ]
div <- summary(gi.regent10_museum)
div$NA.perc # 21.8% missing

#change the pop to age and region in the genlight
pop.data1 <- read.csv("nowrecent.csv", header = TRUE)
gl.regent10_nomuseum@ind.names == pop.data1$gl.regent_nomuseum.ind.names #all lined up
pop(gl.regent10_nomuseum) <- as.factor(pop.data1$pop)
popNames(gl.regent10_nomuseum) # grouped by contemporary age and region
#repeat for museum
pop.data.mus <- read.csv("museum.csv", header = TRUE)
pop(gl.regent10_museum) <- as.factor(pop.data.mus$pop)
popNames(gl.regent_museum) # grouped by region
gl.regent10_museum@ind.names == pop.data.mus$ID # ALL lined up


#####################  pairwise Fst from stAMPP ####################################
# back to the filtered genlight contemporary:

gl.regent_nomuseum #570 loci
pwfst_nomus <- stamppFst(gl.regent10_nomuseum, nboots=10000,
                         percent=95, nclusters=1)
summary(pwfst_nomus)
pwfst_nomus$Fsts
pwfst_nomus$Pvalues
#Adjust the P-values for FDR
p.adjust(pwfst_nomus$Pvalues, method = "fdr")

#####repeat for museum:
pwfst_mus <-stamppFst(gl.regent10_museum, nboots=10000,
                      percent=95, nclusters=1) # 570 SNPs, but more missing data
summary(pwfst_mus)
pwfst_mus$Fsts
p.adjust(pwfst_mus$Pvalues, method = "fdr")

################### Brenton's Fst/logdist plot:

Brentonplot <- read.csv("Brenton_plot_10.csv", header=TRUE) 
#this is just the FST values and 'geogdist' is the linear distance between the central sample
#point wihtin each a-priori population
head(Brentonplot)

## GGPLOT FST/(1-FST) by log(geog dist)

museumplot <- subset(Brentonplot, Brentonplot$period == "1")
muslm <- lm(museumplot$log.geogdist ~ museumplot$Fst.1.fst)
summary(muslm)

contemplot <- subset(Brentonplot, Brentonplot$period == "2")
conlm <- lm(contemplot$Fst.1.fst ~ contemplot$log.geogdist.)
summary(conlm)

# So there is no sig diff in genetic differentiation in either dataset with increasing geog distance.

# Make left hand plot
left_museum <- ggplot(museumplot, aes(log.geogdist. , Fst.1.fst))+
  geom_point()+
  theme_bw() +
  theme(panel.grid.major.y = element_blank()) + 
  theme(panel.grid.minor.y = element_blank()) +
  theme(panel.grid.major.x = element_blank()) + 
  theme(panel.grid.minor.x = element_blank()) +
  xlab(NULL) +
  ylab(expression("F"[ST]*"/(1-F"[ST]*")")) +
  theme(axis.title.y=element_text(size=13, margin=margin(0,16,0,0))) +
  theme(axis.title.x=element_text(size=13, margin=margin(16,0,0,0))) +
  theme(axis.text = element_text(size = 13)) +
  theme(plot.margin = unit(c(0.8,0.8,0.8,0.8), "lines")) +
  guides(alpha=FALSE) +
  theme(legend.position="none") +
  theme(panel.border = element_blank()) +
  theme(axis.line.x = element_line(color="black", size = 0.5), 
        axis.line.y = element_line(color="black", size = 0.5)) +
  geom_smooth(aes(group = period), color="mediumseagreen", method = "lm", se=TRUE, linetype=1, size=0.8) +
  scale_y_continuous(expand = c(0,0), limits=c(-0.01,0.02)) +
  scale_x_continuous(expand=c(0,0), limits=c(1.6,3.2)) +
  coord_cartesian(xlim=c(2.55,3.2), ylim=c(0,0.02)) +
  annotate("text", x = 2.65, y = 0.018, label = ("R^2==-0.12"), parse=TRUE) +
  annotate("text", x = 2.65, y = 0.0165, label = ("p==0.8"), parse=TRUE)

left_museum

# Make right-hand plot
right_contemp <- ggplot() +
  geom_point(data=contemplot, aes(x=log.geogdist. , y=Fst.1.fst), color="black") +
  theme_bw() +
  theme(panel.grid.major.y = element_blank()) + 
  theme(panel.grid.minor.y = element_blank()) +
  theme(panel.grid.major.x = element_blank()) + 
  theme(panel.grid.minor.x = element_blank()) +
  xlab(NULL) +
  ylab(NULL) +
  theme(axis.title.y=element_text(size=13, margin=margin(0,0,0,0))) +
  theme(axis.title.y=element_blank(),
        axis.text.y=element_blank(),
        axis.ticks.y=element_blank()) +
  theme(axis.title.x=element_text(size=13, margin=margin(16,0,0,0))) +
  theme(axis.text = element_text(size = 13)) +
  theme(plot.margin = unit(c(0.8,5,0.8,0.8), "lines")) +
  guides(alpha=FALSE) +
  theme(legend.position="none") +
  theme(panel.border = element_blank()) +
  theme(axis.line.x = element_line(color="black", size = 0.5),
        axis.line.y = element_line(color="black", size = 0.5)) +
  geom_smooth(data=contemplot, aes(x=log.geogdist. , y=Fst.1.fst, group = "period"),
              color = "yellow", method = "lm", se=TRUE, linetype=1, size=0.8) +
  scale_y_continuous(expand = c(0,0), limits=c(-0.01,0.05)) +
  scale_x_continuous(expand=c(0,0), limits=c(1.4,3.2), breaks=c(1.9, 2.2, 2.5, 2.8)) +
  coord_cartesian(xlim=c(1.59,2.95), ylim=c(0,0.02)) +
  annotate("text", x = 1.85, y = 0.018, label = ("R^2==0.02"), parse=TRUE) +
  annotate("text", x = 1.85, y = 0.0165, label = ("p==0.3"), parse=TRUE)

right_contemp

# install.packages("ggpubr")
grid.arrange(left_museum, right_contemp, ncol=2,
             bottom=text_grob("log(geographic distance in km)"))


######################### AMOVA in poppr (see below for repeat in stAMPP) ########################
#create a genclone object
gc.regent_nomuseum <- read.genalex("GENALEX_NOWRECENT_DP10.csv", ploidy = 2, geo= TRUE,
                                   genclone = TRUE, sep = ",", recode=FALSE)
#filter data with >25% missing
gc.regent_nomuseum.f <- missingno(gc.regent_nomuseum, type = "loci", cutoff = 0.25)#removes 335 loci
gc.regent_nomuseum.f
#use missingno to compute the nomean values for remaining missing data:
gc.regent_nomuseum.f <- missingno(gc.regent_nomuseum.f, type = "nomean") #replaced 2694 missing values
nomuseum.amova <- poppr.amova(gc.regent_nomuseum.f, ~ Pop)
set.seed(1999)
nomuseum.amova$results
nomuseum.amova$componentsofcovariance
nomuseum.amova.signif <- randtest(nomuseum.amova, nrepet = 999, p.adjust = "fdr")
nomuseum.amova.signif
plot(nomuseum.amova.signif)
nomuseum.amova$statphi # Phi pop total 0.0033 - between pop variance - 0.33%, very low

############### repeat for museum samples################

gc.regent.mus <- read.genalex("GENALEX_MUSEUM_DP10.csv", ploidy = 2, geo= TRUE,
                              genclone = TRUE, sep = ",", recode=FALSE)
#deal with the missing data via missingno
gc.regent.mus.miss <- missingno(gc.regent.mus, type = "loci", cutoff = 0.25) #removed 794 loci
gc.regent.mus.miss #only retains 388 loci- may be better to keep more loci and use nomean alleles
gc.regent.mus <- missingno(gc.regent.mus, type = "nomean")
museum.amova <- poppr.amova(gc.regent.mus, ~ Pop)
museum.amova$results
museum.amova$componentsofcovariance
set.seed(1999)
museum.amova.signif <- randtest(museum.amova, nrepet = 999, p.adjust = "fdr")
museum.amova.signif
musplot <- plot(museum.amova.signif)
museum.amova # Phi-pop-total 0.00464 - between pop variance = 0.46%

################################# POPULATION-LEVEL BOOTSTRAPPED DENGROGRAMS #######################
###################################################################################################
#contemporary
gi.regent10_nomuseum <- gl2gi(gl.regent10_nomuseum)
#Gst_Hedrick
Hedrick.gst_nomus <- Gst_Hedrick(gi.regent10_nomuseum)
Hedrick.gst_nomus$global #treat negative values as ZERO

#calculate Provesti's genetic distance, which handles missing data:
nomuseum_dist <- provesti.dist(gi.regent10_nomuseum)
levels(gi.regent10_nomuseum@pop)
#pop(gi.regent10_nomuseum) <- as.factor(pop.data1$pop) do if needed

par(mfrow=c(1,1))
# Analysis
set.seed(1000)
tree_nomus <- gi.regent10_nomuseum %>%
  genind2genpop(pop = ~pop) %>%
  aboot(cutoff = 50, quiet = TRUE, sample = 10000, root = FALSE, distance = provesti.dist) #looks good

#try with missing data ignored
gi.regent10_nomuseum %>%
  genind2genpop(pop = ~pop) %>%
  aboot(cutoff = 50, quiet = TRUE, sample = 10000, root = FALSE,
        missing="zero", distance = provesti.dist) #makes no difference

#musueum
gi.regent10_museum <- gl2gi(gl.regent10_museum)
#Gst_Hedrick
Hedrick.gst_mus <- Gst_Hedrick(gi.regent10_museum)
Hedrick.gst_mus$global #treat negative values as ZERO

#calculate Provesti's genetic distance, which handles missing data:
museum_dist <- provesti.dist(gi.regent10_museum)
pop(gi.regent10_museum) <- as.factor(pop.data.mus$pop)
levels(gi.regent10_museum@pop)

# Analysis
set.seed(1000)
gi.regent10_museum %>%
  genind2genpop(pop = ~pop) %>%
  aboot(cutoff = 50, quiet = TRUE, sample = 10000, root = FALSE, distance = provesti.dist) #looks good

##################################### DAPC using adegenet#######################################
################################################################################################

##### recent samples:
gi.regent10_nomuseum

grp <- find.clusters(gi.regent10_nomuseum, max.n.clust= 5) #retain all PCs
names(grp)
head(grp$Kstat, 8)
table(pop(gi.regent10_nomuseum), grp$grp)
table.value(table(pop(gi.regent10_nomuseum), grp$grp), col.lab=paste("inf", 1:3),
            row.lab=paste("ori", 1:5))
# dapc
dapc1 <- dapc(gi.regent10_nomuseum, grp$pop)#60 PCs , 4 DFs
scatter(dapc1)#basic

scatter(dapc1, posi.da="bottomright", bg="white", pch=17:22) #better

myCol <- c("darkblue","lightblue","darkred","red","gold")
scatter(dapc1, posi.da="bottomright", bg="white",
        pch=17:22, cstar=0, col=myCol,
        posi.pca="bottomleft")
scatter(dapc1, scree.da=FALSE, bg="white", pch=20, cstar=0, col=myCol, solid=.4,
        cex=3,clab=0, leg=TRUE)

scatter(dapc1, ratio.pca=0.3, bg="white", pch=20,
        cstar=0, col=myCol, solid=.4, cex=2, clab=0,
        mstree=TRUE, scree.da=FALSE, posi.pca="bottomright",
        leg=TRUE, posi.leg = "topleft")
par(xpd=FALSE)
points(dapc1$grp.coord[,1], dapc1$grp.coord[,2], pch=4,
       cex=2, lwd=8, col="black")
points(dapc1$grp.coord[,1], dapc1$grp.coord[,2], pch=4,
       cex=2, lwd=2, col=myCol)

myInset <- function(){
  temp <- dapc1$pca.eig
  temp <- 100* cumsum(temp)/sum(temp)
  plot(temp, col=rep(c("black","lightgrey"),
                     c(dapc1$n.pca,1000)), ylim=c(0,100),
       xlab="PCA axis", ylab="Cumulative variance (%)",
       cex=1, pch=20, type="h", lwd=2)
}
add.scatter(myInset(), posi="bottomleft",
            inset=c(0,0), ratio=.18,
            bg=transp("white"))

compoplot(dapc1, main="contemporary", posi="bottomright",
          ncol=1, xlab="individuals", col=myCol)
#dapc1$posterior  #save these for plotting compoplot grouped by pop

#alpha scores:
dapc2 <- dapc(gi.regent10_nomuseum, n.da=4, n.pca=14)
temp <- a.score(dapc2)
temp_nomus <- optim.a.score(dapc2) #optimal number of PCs is 14
compoplot(dapc2, main="contemporary", posi="bottomright",
          ncol=1, xlab="individuals", col=myCol)

#cross-validation:
x <- gi.regent10_nomuseum
grp <- pop(x)
x <- tab(x, NA.method="nomean")
mat <- as.matrix(x)
xval <- xvalDapc(x, grp, n.pca.max = 20, training.set = 0.9,
                 result = "groupnomean", center = TRUE, scale = FALSE,
                 n.pca = NULL, n.rep = 40, xval.plot = TRUE)
xval[2:6] #30

#validation using supplementary individuals

set.seed(2)
kept.id <- unlist(tapply(1:nInd(gi.regent10_nomuseum), pop(gi.regent_nomuseum),
                         function(e) sample(e, 10, replace=FALSE)))
x.sup <- gi.regent10_nomuseum[kept.id]
x <- gi.regent10_nomuseum[-kept.id]
nInd(x)
## 103
nInd(x.sup)
## 50

dapc4 <- dapc(x,n.pca=50,n.da=4) #use the criteria identified as best above
pred.sup <- predict.dapc(dapc4, newdata=x.sup)
names(pred.sup)
head(pred.sup$assign)
pred.sup$ind.scores[1:5,1:3]
round(pred.sup$posterior[1:5, 1:5],3)

col <- rainbow(length(levels(pop(x))))
col.points <- transp(col[as.integer(pop(x))],.2)
scatter(dapc4, col=col, bg="white", scree.da=0, pch="",
        cstar=0, clab=0, xlim=c(-5,5), legend=TRUE)
par(xpd=TRUE)
points(dapc4$ind.coord[,1], dapc4$ind.coord[,2], pch=20,
       col=col.points, cex=5)
col.sup <- col[as.integer(pop(x.sup))]
points(pred.sup$ind.scores[,1], pred.sup$ind.scores[,2], pch=15,
       col=transp(col.sup,.7), cex=2)
add.scatter.eig(dapc4$eig,15,1,2, posi="bottomright", inset=.02)

nomean(as.character(pred.sup$assign)==as.character(pop(x.sup))) #only 24% assigned correctly
table.value(table(pred.sup$assign, pop(x.sup)), col.lab=levels(pop(x.sup))) #columns = actual clusters, rows = inferred clusters


################  museum DAPC #####################################

gi.regent10_museum$pop

grp1 <- find.clusters(gi.regent10_museum, max.n.clust= 5)
#retain 60PCs and 5 clusters (even though 1 is best)
head(grp1$Kstat, 8)
table(pop(gi.regent10_museum), grp1$grp)
table.value(table(pop(gi.regent_museum), grp1$grp), col.lab=paste("inf", 1:5),
            row.lab=paste("ori", 1:5))
# dapc
dapc_mus <- dapc(gi.regent10_museum, grp1$pop)#20 PCs , 4DFs
scatter(dapc_mus)#basic

myCol <- c("green","purple","gold","blue","red")
scatter(dapc_mus, posi.da="bottomright", bg="white",
        pch=17:22, cstar=0, col=myCol,
        posi.pca="bottomleft")

scatter(dapc_mus, scree.da=FALSE, bg="white", pch=20, cstar=0, col=myCol, solid=.4,
        cex=3,clab=0, leg=TRUE)

scatter(dapc_mus, ratio.pca=0.5, bg="white", main = "historic (1879 - 1966)", pch=20,
        cstar=0, col=myCol, solid=.4, cex=3, clab=0,
        mstree=TRUE, scree.da=FALSE, posi.pca="bottomright",
        leg=TRUE, posi.leg = "topleft")
points(dapc_mus$grp.coord[,1], dapc_mus$grp.coord[,2], pch=4,
       cex=2, lwd=8, col="black")
points(dapc_mus$grp.coord[,1], dapc_mus$grp.coord[,2], pch=4,
       cex=2, lwd=2, col=myCol)

myInset1 <- function(){
  temp <- dapc_mus$pca.eig
  temp <- 100* cumsum(temp)/sum(temp)
  plot(temp, col=rep(c("black","lightgrey"),
                     c(dapc_mus$n.pca,1000)), ylim=c(0,100),
       xlab="PCA axis", ylab="Cumulated variance (%)",
       cex=1, pch=20, type="h", lwd=2)
}
add.scatter(myInset1(), posi="bottomleft",
            inset=c(0,-0.04), ratio=.18,
            bg=transp("white"))

compoplot(dapc_mus, main="historic", posi="bottomright",
          ncol=1, xlab="", col=myCol) #not ordered by a-priori population
#dapc_mus$posterior

#alpha scores:
dapc2 <- dapc(gi.regent10_museum, n.da=4, n.pca=20)
temp <- a.score(dapc2)
temp_mus <- optim.a.score(dapc2) #optimal number of PCs is 8- 
compoplot(dapc2, main="contemporary", posi="bottom",
          ncol=1, xlab="individuals", col=myCol)

#cross-validation:
y <- gi.regent10_museum
grp <- pop(y)
y <- tab(y, NA.method="nomean")
mat <- as.matrix(y)
xval <- xvalDapc(y, grp, n.pca.max = 50, training.set = 0.9,
                 result = "groupnomean", center = TRUE, scale = FALSE,
                 n.pca = NULL, n.rep = 20, xval.plot = TRUE)
xval[2:6]
#10 PCs achieves the lowest MSE

#validation using supplementary individuals

set.seed(2)
kept.id <- unlist(tapply(1:nInd(gi.regent10_museum), pop(gi.regent10_museum),
                         function(e) sample(e, 3, replace=FALSE)))
x.sup_mus <- gi.regent10_museum[kept.id]
x_mus <- gi.regent10_museum[-kept.id]
nInd(x_mus)
## 46
nInd(x.sup_mus)
## 15

dapc5 <- dapc(x_mus,n.pca=10,n.da=4) #use the criteria identified as best above
pred.sup_mus <- predict.dapc(dapc5, newdata=x.sup_mus)
head(pred.sup_mus$assign)
pred.sup_mus$ind.scores[1:5,1:3]
round(pred.sup_mus$posterior[1:5, 1:3],3)

col <- rainbow(length(levels(pop(x_mus))))
col.points <- transp(col[as.integer(pop(x_mus))],.2)
scatter(dapc5, col=col, bg="white", scree.da=0, pch="",
        cstar=0, clab=0, xlim=c(-5,5), legend=TRUE)
par(xpd=TRUE)
points(dapc5$ind.coord[,1], dapc5$ind.coord[,2], pch=20,
       col=col.points, cex=5)
col.sup <- col[as.integer(pop(x.sup_mus))]
points(pred.sup_mus$ind.scores[,1], pred.sup_mus$ind.scores[,2], pch=15,
       col=transp(col.sup,.7), cex=2)
add.scatter.eig(dapc5$eig,15,1,2, posi="bottomright", inset=.02)

nomean(as.character(pred.sup_mus$assign)==as.character(pop(x.sup_mus))) #only 20% assigned correctly
table.value(table(pred.sup_mus$assign, pop(x.sup_mus)), col.lab=levels(pop(x.sup_mus)))
#columns = actual clusters, rows = inferred clusters

#####################DAPC compoplot ############################################
#the csv files are made from the posterior probabilities from #dapc$posterior
#reorder the samples in the csv by a-priori population, then plot them:

contemporary <- read.csv("DAPC_contemporary_DP10.csv", header = TRUE)

fill <- c("royalblue3","red3","steelblue1","lightsalmon","gold")
P4 <- ggplot() + geom_bar(aes(y = prob, x = order, fill = pop), data = contemporary,
                          stat="identity")
P4 <- P4 + scale_fill_manual(values = fill)
P4

museum <- read.csv("DAPC_museum_DP10.csv", header = TRUE)
fill <- c("olivedrab2","royalblue3","red3","gold","plum3")
p5 <- ggplot() + geom_bar(aes(y=prob, x = order, fill = pop), data = museum,
                          stat = "identity")
p5 <- p5 + scale_fill_manual(values = fill)
p5

grid.arrange(p5,P4, nrow = 2)

#####################################################################################################
##################isolation by distance plots and mantel tests########################################

#contemporary
gi.regent.nomus <- read.genalex("GENALEX_NOWRECENT_DP10_100_50.csv", ploidy = 2, geo= TRUE,
                                genclone = FALSE, sep = ",", recode=FALSE)
#deal with the missing data via missingno
gi.regent.nomus <- missingno(gi.regent.nomus, type = "loci", cutoff = 0.25)
#gi.regent.mus <- missingno(gc.regent.mus.miss, type = "nomean") #not done but could be done
# Yep do wherever you can.
gd_nomus <- dist(gi.regent.nomus$other$xy, method= "euclidean")
#bd_nomus <- bitwise.dist(gi.regent.nomus)
bd_nomus <- dist(gi.regent.nomus, method = "euclidean", diag = FALSE, upper = FALSE, p = 2) # Just testing an alternative method
mantel_nomus <- mantel.randtest(bd_nomus,gd_nomus, nrepet = 1000, alter="two-sided")
mantel_nomus
plot(mantel_nomus, main="contemporary")
plot(gd_nomus, bd_nomus)
abline(lm(bd_nomus~gd_nomus), col="red",lty=2)
dens <- kde2d(gd_nomus,bd_nomus, n=300)
myPal <- colorRampPalette(c("white","blue","gold", "orange", "red"))
plot(gd_nomus, bd_nomus, pch=20,cex=.5,main = "Contemporary", xlab = "geographic distance (100s of KMs)",
     ylab = "genetic distance")
image(dens, col=transp(myPal(300),.7), add=TRUE)
clip(0,9,0,17)
abline(lm(bd_nomus~gd_nomus), col="red",lty=2) #abline doesnt show up for some reason

#museum
gi.regent.mus <- read.genalex("GENALEX_MUSEUM_DP10_100_50.csv", ploidy = 2, geo= TRUE,
                              genclone = FALSE, sep = ",", recode=FALSE)
#deal with the missing data via missingno
gi.regent.mus <- missingno(gi.regent.mus, type = "loci", cutoff = 0.25)
#gi.regent.mus <- missingno(gc.regent.mus.miss, type = "nomean") #not done but could be done
gd_mus <- dist(gi.regent.mus$other$xy, method= "euclidean")
# bd_mus <- bitwise.dist(gi.regent.mus)
bd_mus <- dist(gi.regent.mus, method = "euclidean", diag = FALSE, upper = FALSE, p = 2) # Just testing an alternative method
mantel_mus <- mantel.randtest(bd_mus,gd_mus, nrepet = 1000, alter="two-sided")
mantel_mus # Seems better
plot(mantel_mus, main="Historic")
plot(gd_mus, bd_mus)
abline(lm(bd_mus~gd_mus), col="red",lty=2)
dens <- kde2d(gd_mus,bd_mus, n=300)
myPal <- colorRampPalette(c("white","blue","gold", "orange", "red"))
plot(gd_mus, bd_mus, pch=20,cex=.5, main = "Historic", xlab = "", ylab = "genetic distance")
image(dens, col=transp(myPal(300),.7), add=TRUE)
clip(0,16.5,0,0.18)
abline(lm(bd_mus~gd_mus), col="red",lty=2)

###################################### GENETIC DIVERSITY METRICS ##################################
###################################################################################################

gl.regent@ind.names == pop.data$ID # ALL lined up
gi.regent.f@pop
gi.regent.f

regent.gx <- read.genalex("hyRAD_MUS_DP15_max100.f2.csv", ploidy = 2, 
                          geo = FALSE, region = FALSE,
                          genclone = FALSE, sep = ",", recode = FALSE)
#you can redo the analysis with and or without the next 2 lines of filtering steps
regent.gx <- missingno(regent.gx, type = "loci", cutoff = 0.65) #removed 44loci in the 60% present dataset
regent.gx.mean <- missingno(regent.gx, type = "mean")

basic.stats.nomean <- basic.stats(regent.gx)
basic.stats.mean <- basic.stats(regent.gx.mean)

#save Ho as a data frame
Ho_regent_nomean <- data.frame(basic.stats.nomean$Ho)
head(Ho_regent_nomean)

Ho_regent_mean <- data.frame(basic.stats.mean$Ho)
head(Ho_regent_mean)
#save Hs as a data frame
Hs_regent_nomean <- data.frame(basic.stats.nomean$Hs)
Hs_regent_mean <- data.frame(basic.stats.mean$Hs)
head(Hs_regent_mean)
#calclulate rarefied allelic counts per locus and population:
Ar_regent_nomean <- allelic.richness(regent.gx,diploid=TRUE)
Ar_regent_mean <- allelic.richness(regent.gx.mean,diploid=TRUE)
Ar_regent1_nomean <- data.frame(Ar_regent_nomean$Ar)
Ar_regent1_mean <- data.frame(Ar_regent_mean$Ar)
names(Ar_regent1_nomean) <- c("Historic", "Recent", "Current")
names(Ar_regent1_mean) <- c("Historic", "Recent", "Current")
head(Ar_regent1_nomean)
head(Ar_regent1_mean)


#reporting FIS values (inbreeding coefficients)
Fis_regent_nomean <- data.frame(basic.stats.nomean$Fis)
Fis_regent_mean <- data.frame(basic.stats.mean$Fis)
head(Fis_regent_nomean) # Negative values suggest outbreeding - this is expected considering how little genetic differentiation
# there is between 'populations'

#Mann-Whitney tests on Hs and Ar over time, no missing data interpolated:
wilcox.test(Hs_regent_nomean$Historic, Hs_regent_nomean$Recent, paried=FALSE, altenative = "two.sided")
wilcox.test(Hs_regent_nomean$Historic, Hs_regent_nomean$Current, paried=FALSE, altenative = "two.sided")
wilcox.test(Hs_regent_nomean$Recent, Hs_regent_nomean$current, paried=FALSE, altenative = "two.sided")
wilcox.test(Ho_regent_nomean$Historic, Ho_regent_nomean$Recent, paried=FALSE, altenative = "two.sided")
wilcox.test(Ho_regent_nomean$Historic, Ho_regent_nomean$Current, paried=FALSE, altenative = "two.sided")
wilcox.test(Ho_regent_nomean$Recent, Ho_regent_nomean$current, paried=FALSE, altenative = "two.sided")
wilcox.test(Ar_regent1_nomean$Historic, Ar_regent1_nomean$Recent, paired=FALSE, alternative= "two.sided")
wilcox.test(Ar_regent1_nomean$Historic, Ar_regent1_nomean$Current, paired=FALSE, alternative= "two.sided")
wilcox.test(Ar_regent1_nomean$Recent, Ar_regent1_nomean$Current, paired=FALSE, alternative= "two.sided") 


#Mann-Whitney tests on Hs and Ar over time, with missing data interpolated:
hs_hisrec <- wilcox.test(Hs_regent_mean$historic, Hs_regent_mean$recent, paried=FALSE, altenative = "two.sided")
hs_hiscur <- wilcox.test(Hs_regent_mean$historic, Hs_regent_mean$current, paried=FALSE, altenative = "two.sided")
hs_reccur <- wilcox.test(Hs_regent_mean$recent, Hs_regent_mean$current, paried=FALSE, altenative = "two.sided")
ho_hisrec <- wilcox.test(Ho_regent_mean$historic, Ho_regent_mean$recent, paried=FALSE, altenative = "two.sided")
ho_hiscur <- wilcox.test(Ho_regent_mean$historic, Ho_regent_mean$current, paried=FALSE, altenative = "two.sided")
ho_reccur <- wilcox.test(Ho_regent_mean$recent, Ho_regent_mean$current, paried=FALSE, altenative = "two.sided")
fs_hisrec <- wilcox.test(Fis_regent_mean$historic, Fis_regent_mean$recent, paried=FALSE, altenative = "two.sided")
fs_hiscur <- wilcox.test(Fis_regent_mean$historic, Fis_regent_mean$current, paried=FALSE, altenative = "two.sided")
fs_reccur <- wilcox.test(Fis_regent_mean$recent, Fis_regent_mean$current, paried=FALSE, altenative = "two.sided")
ar_hisrec <- wilcox.test(Ar_regent1_mean$Historic, Ar_regent1_mean$Recent, paired=FALSE, alternative= "two.sided")
ar_hiscur <- wilcox.test(Ar_regent1_mean$Historic, Ar_regent1_mean$Current, paired=FALSE, alternative= "two.sided")
ar_reccur <- wilcox.test(Ar_regent1_mean$Recent, Ar_regent1_mean$Current, paired=FALSE, alternative= "two.sided") 
# Brenton: These tests are probably very sensitive and I wouldn't read too much into them.
# The actual mean values of all the genetic parameters (Hs, Ho, Fis, Ar) are very similar and that's what counts!

boxplot(Ho_regent_nomean)
boxplot(Ho_regent_mean)
boxplot(Hs_regent_nomean)
boxplot(Hs_regent_mean)
boxplot(Fis_regent_mean)
boxplot(Fis_regent_nomean)
boxplot(Ar_regent1_nomean)
boxplot(Ar_regent1_mean) 

p.adjust(hs_hisrec$p.value, method = "fdr")
p.adjust(hs_hiscur$p.value, method = "fdr") 
p.adjust(hs_reccur$p.value, method = "fdr")
p.adjust(ho_hisrec$p.value, method = "fdr")
p.adjust(ho_hiscur$p.value, method = "fdr")
p.adjust(ho_reccur$p.value, method = "fdr")
p.adjust(Fs_hisrec$p.value, method = "fdr")
p.adjust(ar_hisrec$p.value, method = "fdr")
p.adjust(ar_hiscur$p.value, method = "fdr")
p.adjust(ar_reccur$p.value, method = "fdr") 

df_mean <- data.frame(melt(Ho_regent_mean), melt(Hs_regent_mean),
                        melt(Fis_regent_mean)[2])
head(df_mean)
names(df_mean) <- c("column", "Ho", "column1", "Hs", "Fis")
df2_mean <- melt(df_mean)
head(df2_mean)
df2_mean <- df2_mean[,-2]
#rename the age factors for the plot:
#levels(df2_nomean$column)[levels(df2_nomean$column)=="historic"] <- "Historic"
#levels(df2_nomean$column)[levels(df2_nomean$column)=="recent"] <- "Recent"
#levels(df2_nomean$column)[levels(df2_nomean$column)=="current"] <- "Current"

# re-order the levels in the order of appearance in the data.frame

df2_mean$column <- factor(df2_mean$column, c("Historic", "Recent", "Current"))

#plot Ho Hs and Fis together:
geneticparams_mean <- ggplot(data=df2_mean) +
  geom_boxplot(aes(x=variable, y=value, fill=column), position = position_dodge(0.8)) +
  theme_bw() +
  theme(panel.grid.major.y = element_blank()) +  
  theme(panel.grid.minor.y = element_blank()) +
  theme(panel.grid.major.x = element_blank()) +  
  theme(panel.grid.minor.x = element_blank()) +
  theme(text=element_text(family="serif"))+
  xlab("Genetic parameter") + 
  ylab("Value") +
  theme(axis.title.y=element_text(size=14, margin=margin(0,16,0,0))) +
  theme(axis.title.x=element_text(size=14, margin=margin(16,0,0,0))) +
  theme(axis.text = element_text(size = 14)) +
  scale_fill_manual(labels=c("Historic","Recent", "Current"), 
                    values = c("mediumseagreen","yellow","royalblue1")) +
  guides(fill=guide_legend(title="Period")) +
  theme(panel.border = element_blank()) +
  theme(axis.line.x = element_line(color="black", size = 0.5), 
        axis.line.y = element_line(color="black", size = 0.5))

geneticparams_mean

# This plot allows easy visualisation of the high level of similarity between the time periods.
# It also shows the high observed heterozygosities

#Repeat with dataset where missing data replaces with mean values:
df_mean <- data.frame(melt(Ho_regent_mean), melt(Hs_regent_mean),
                        melt(Fis_regent_mean)[2])
head(df_mean)
names(df_mean) <- c("column", "Ho", "column1", "Hs", "Fis")
df2_mean <- melt(df_mean)
head(df2_mean)
df2_mean <- df2_mean[,-2]
#rename the age factors for the plot:
levels(df2_mean$column)[levels(df2_mean$column)=="historic"] <- "Historic"
levels(df2_mean$column)[levels(df2_mean$column)=="recent"] <- "Recent"
levels(df2_mean$column)[levels(df2_mean$column)=="current"] <- "Current"

# re-order the levels in the order of appearance in the data.frame

df2_mean$column <- factor(df2_mean$column, c("Historic", "Recent", "Current"))

#plot Ho Hs and Fis together:
geneticparams_mean <- ggplot(data=df2_mean) +
  geom_boxplot(aes(x=variable, y=value, fill=column), position = position_dodge(0.8)) +
  theme_bw() +
  theme(panel.grid.major.y = element_blank()) +  
  theme(panel.grid.minor.y = element_blank()) +
  theme(panel.grid.major.x = element_blank()) +  
  theme(panel.grid.minor.x = element_blank()) +
  theme(text=element_text(family="serif"))+
  xlab("Genetic parameter") + 
  ylab("Value") +
  theme(axis.title.y=element_text(size=14, margin=margin(0,16,0,0))) +
  theme(axis.title.x=element_text(size=14, margin=margin(16,0,0,0))) +
  theme(axis.text = element_text(size = 14)) +
  scale_fill_manual(labels=c("Historic","Recent", "Current"), 
                    values = c("mediumseagreen","yellow","royalblue1")) +
  guides(fill=guide_legend(title="Period")) +
  theme(panel.border = element_blank()) +
  theme(axis.line.x = element_line(color="black", size = 0.5), 
        axis.line.y = element_line(color="black", size = 0.5))

geneticparams_mean

#repeat by region in the recent and current samples, with missingno computed:

regent.gx.nomus <- read.genalex("GENALEX_NOWRECENT_DP15_100_50.csv", ploidy = 2, 
                                geo = FALSE, region = FALSE,
                                genclone = FALSE, sep = ",", recode = FALSE)
regent.gx.nomus <- missingno(regent.gx.nomus, type = "loci", cutoff = 0.35)
regent.gx.nomus <- missingno(regent.gx.nomus, type = "mean")
levels(regent.gx.nomus$pop)
basic.stats.nomus <- basic.stats(regent.gx.nomus)

Hs_regent.nomus <- data.frame(basic.stats.nomus$Hs)
Ho_regent.nomus <- data.frame(basic.stats.nomus$Ho)
Fis_regent.nomus <- data.frame(basic.stats.nomus$Fis)
#calclulate rarefied allelic counts per locus and population:
Ar_regent.nomus <- allelic.richness(regent.gx.nomus,diploid=TRUE)
Ar_regent_nomus <- data.frame(Ar_regent.nomus$Ar)


#stats within contemporary populations:
wilcox.test(Hs_regent_nomus$recentNNSW, Hs_regent_nomus$currentNNSW, paried=FALSE, altenative = "two.sided")
wilcox.test(Hs_regent_nomus$recentBMTN, Hs_regent_nomus$currentBMTN, paried=FALSE, altenative = "two.sided")
wilcox.test(Hs_regent_nomus$currentBMTN, Hs_regent_nomus$currentNNSW, paried=FALSE, altenative = "two.sided")
wilcox.test(Ar_regent_nomus$X1, Ar_regent_nomus$X4, paired=FALSE, alternative= "two.sided") #nowBMTN v recentBMTN
wilcox.test(Ar_regent_nomus$X2, Ar_regent_nomus$X3, paired=FALSE, alternative= "two.sided") #nowNNSW v recent NNSW
wilcox.test(Ar_regent_nomus$X1, Ar_regent_nomus$X2, paried=FALSE, altenative = "two.sided") #nowNNSW v nowBMTN
wilcox.test(Ar_regent1$X2, Ar_regent1$X3, paired=FALSE, alternative= "two.sided")

df3 <- data.frame(melt(Ho_regent.nomus), melt(Hs_regent.nomus), melt(Fis_regent.nomus)[2])
head(df3)
df3 <- df3[,-3]
names(df3) <- c("column", "Ho", "Hs", "Fis")
head(df3)
df3 <- melt(df3)
#rename the age factors for the plot:
levels(df3$column)


#plot Ho Hs and Fis together:
geneticparams_nomus_mean <- ggplot(data=df3) +
  geom_boxplot(aes(x=variable, y=value, fill=column), position = position_dodge(0.8)) +
  theme_bw() +
  theme(panel.grid.major.y = element_blank()) +  
  theme(panel.grid.minor.y = element_blank()) +
  theme(panel.grid.major.x = element_blank()) +  
  theme(panel.grid.minor.x = element_blank()) +
  theme(text=element_text(family="serif"))+
  xlab("Genetic parameter") + 
  ylab("Value") +
  theme(axis.title.y=element_text(size=14, margin=margin(0,16,0,0))) +
  theme(axis.title.x=element_text(size=14, margin=margin(16,0,0,0))) +
  theme(axis.text = element_text(size = 14)) +
  scale_fill_manual(labels=c("CurrentBMT", "CurrentNNSW", "RecentNNSW",
                             "RecentBMTN","RecentNVIC"), 
                    values = c("royalblue2","red2","lightsalmon","lightskyblue1", "goldenrod1")) +
  guides(fill=guide_legend(title="Period")) +
  theme(panel.border = element_blank()) +
  theme(axis.line.x = element_line(color="black", size = 0.5), 
        axis.line.y = element_line(color="black", size = 0.5))

geneticparams_nomus_mean

names(Ar_regent_nomus) <- c("currentBMTN", "currentNNSW", "recentNNSW", "recentBMTN","recentNVIC")
boxplot(Ar_regent_nomus)
Ar_nomus <- melt(Ar_regent_nomus)
head(Ar_nomus)

Alleleplot_nomus_nomean <- ggplot(data=Ar_nomus) +
  geom_boxplot(aes(x=variable, y=value, fill=variable), position = position_dodge(0.8)) +
  theme_bw() +
  theme(panel.grid.major.y = element_blank()) +  
  theme(panel.grid.minor.y = element_blank()) +
  theme(panel.grid.major.x = element_blank()) +  
  theme(panel.grid.minor.x = element_blank()) +
  theme(text=element_text(family="serif"))+
  xlab("Population") + 
  ylab("Ar") +
  theme(axis.title.y=element_text(size=14, margin=margin(0,16,0,0))) +
  theme(axis.title.x=element_text(size=14, margin=margin(16,0,0,0))) +
  theme(axis.text = element_text(size = 14)) +
  scale_fill_manual(labels=c("CurrentBMT", "CurrentNNSW", "RecentNNSW",
                             "RecentBMTN","RecentNVIC"), 
                    values = c("royalblue2","red2","lightsalmon","lightskyblue1", "goldenrod1")) +
  guides(fill=guide_legend(title="Period")) +
  theme(panel.border = element_blank()) +
  theme(axis.line.x = element_line(color="black", size = 0.5), 
        axis.line.y = element_line(color="black", size = 0.5))

Alleleplot_nomus_nomean 


plot_grid(geneticparams_nomus_mean,Alleleplot_nomus_nomean, align= "h", nrow = 2, ncol=1) #still need
#to do the allelplot mean for all three time periods

####################################INDIVIDUAL LEVEL INBREEDING #########################

#install.packages("inbreedR")
library(inbreedR)
library(vcfR)
library(reshape2)

vcf_file <- "hyRAD_MUS_DP15_max100.f2.recode.vcf"
# read vcf
vcf <- read.vcfR(vcf_file, verbose = FALSE )
# extract genotypes
gt <- extract.gt(vcf)
# transpose and data.frame
gt <- as.data.frame(t(gt), stringsAsFactors = FALSE)
#check the order of the data frame:
head(gt[1:10,1:10]) #the problem here is that the ID column isnt actually a 'column' in the DF?

#write the data to file, split by time period and read back in:
write.csv(gt, file = "inbreeding_all_inbreedR.csv")
#Sort the data by ID and save as periods

historic <- read.csv(file = "inbreedR_historic.csv", header=TRUE)
# NA handling
historic[historic == "."] <- NA
# split columns
historic <- do.call(cbind, apply(historic, 2, function(x) colsplit(x, "/", c("a","b"))))
# convert
historic_snp_genotypes <- inbreedR::convert_raw(historic)
# check data
check_data(historic_snp_genotypes)


g2_historic_snps <- g2_snps(historic_snp_genotypes, nperm = 100, nboot = 100, 
                            CI = 0.95, parallel = FALSE, ncores = NULL)
g2_historic_snps

par(mfrow=c(3,1))
plot(g2_historic_snps, main = "Historic",cex.main = 1.5, xlab = "", family = "serif", breaks = 20,
     col = "seagreen", cex.axis=1, cex.lab = 1.3, xlim = c(-0.005, 0.02))

# repeat for recent

recent <- read.csv(file = "inbreedR_recent.csv", header=TRUE)
# NA handling
recent[recent == "."] <- NA
# split columns
recent <- do.call(cbind, apply(recent, 2, function(x) colsplit(x, "/", c("a","b"))))
# convert
recent_snp_genotypes <- inbreedR::convert_raw(recent)
# check data
check_data(recent_snp_genotypes)


g2_recent_snps <- g2_snps(recent_snp_genotypes, nperm = 100, nboot = 100, 
                          CI = 0.95, parallel = FALSE, ncores = NULL)
g2_recent_snps
plot(g2_recent_snps, main = "Recent", cex.main=1.5, xlab = "", family = "serif", breaks = 20,
     col = "yellow", xlim = c(-0.005, 0.02), cex.axis=1, cex.lab = 1.3)

#repeat for current:
current <- read.csv(file = "inbreedR_current.csv", header=TRUE)
# NA handling
current[current == "."] <- NA
# split columns
current <- do.call(cbind, apply(current, 2, function(x) colsplit(x, "/", c("a","b"))))
# convert
current_snp_genotypes <- inbreedR::convert_raw(current)
# check data
check_data(current_snp_genotypes)


g2_current_snps <- g2_snps(current_snp_genotypes, nperm = 100, nboot = 100, 
                           CI = 0.95, parallel = FALSE, ncores = NULL)
g2_current_snps
plot(g2_current_snps, main = "Current", cex.main = 1.5, family = "serif", breaks = 20,
     col = "royalblue",xlim = c(-0.005, 0.02),cex.lab = 1.3, cex.axis=1)

####################################### PRIVATE ALLELES #################################

#by time period
levels(gi.regent.f@pop)
gi.regent.f
private_alleles(gi.regent.f, form = alleles ~ ., report = "table",
                level = "population", count.alleles = TRUE, drop = FALSE) #none detected
#Within historic pop
levels(gi.regent.museum@pop)
private_alleles(gi.regent_mus, form = alleles ~ ., report = "table",
                level = "population", count.alleles = TRUE, drop = FALSE) #there are lots-
#save data frame to csv and run pivot table in excel
#within contemporary pop
levels(gi.regent.nomus@pop)
gi.regent.nomus
private_alleles(gi.regent.nomus, form = alleles ~ ., report = "table",
                level = "population", count.alleles = TRUE, drop = FALSE) #1 in currentBMTN

#these metrics vary a bit by the degree of filtering, but the proportion
#in each population remains fairly consistent across filtering criteria

